# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.coins import top_gainers_loser_get_params
from ..._base_client import make_request_options
from ...types.coins.top_gainers_loser_get_response import TopGainersLoserGetResponse

__all__ = ["TopGainersLosersResource", "AsyncTopGainersLosersResource"]


class TopGainersLosersResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TopGainersLosersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return TopGainersLosersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TopGainersLosersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return TopGainersLosersResourceWithStreamingResponse(self)

    def get(
        self,
        *,
        vs_currency: str,
        duration: Literal["1h", "24h", "7d", "14d", "30d", "60d", "1y"] | NotGiven = NOT_GIVEN,
        top_coins: Literal["300", "500", "1000", "all"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TopGainersLoserGetResponse:
        """
        This endpoint allows you to **query the top 30 coins with largest price gain and
        loss by a specific time duration**

        Args:
          vs_currency: target currency of coins \\**refers to
              [`/simple/supported_vs_currencies`](/reference/simple-supported-currencies).

          duration: filter result by time range Default value: `24h`

          top_coins: filter result by market cap ranking (top 300 to 1000) or all coins (including
              coins that do not have market cap) Default value: `1000`

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/coins/top_gainers_losers",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "vs_currency": vs_currency,
                        "duration": duration,
                        "top_coins": top_coins,
                    },
                    top_gainers_loser_get_params.TopGainersLoserGetParams,
                ),
            ),
            cast_to=TopGainersLoserGetResponse,
        )


class AsyncTopGainersLosersResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTopGainersLosersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTopGainersLosersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTopGainersLosersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncTopGainersLosersResourceWithStreamingResponse(self)

    async def get(
        self,
        *,
        vs_currency: str,
        duration: Literal["1h", "24h", "7d", "14d", "30d", "60d", "1y"] | NotGiven = NOT_GIVEN,
        top_coins: Literal["300", "500", "1000", "all"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TopGainersLoserGetResponse:
        """
        This endpoint allows you to **query the top 30 coins with largest price gain and
        loss by a specific time duration**

        Args:
          vs_currency: target currency of coins \\**refers to
              [`/simple/supported_vs_currencies`](/reference/simple-supported-currencies).

          duration: filter result by time range Default value: `24h`

          top_coins: filter result by market cap ranking (top 300 to 1000) or all coins (including
              coins that do not have market cap) Default value: `1000`

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/coins/top_gainers_losers",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "vs_currency": vs_currency,
                        "duration": duration,
                        "top_coins": top_coins,
                    },
                    top_gainers_loser_get_params.TopGainersLoserGetParams,
                ),
            ),
            cast_to=TopGainersLoserGetResponse,
        )


class TopGainersLosersResourceWithRawResponse:
    def __init__(self, top_gainers_losers: TopGainersLosersResource) -> None:
        self._top_gainers_losers = top_gainers_losers

        self.get = to_raw_response_wrapper(
            top_gainers_losers.get,
        )


class AsyncTopGainersLosersResourceWithRawResponse:
    def __init__(self, top_gainers_losers: AsyncTopGainersLosersResource) -> None:
        self._top_gainers_losers = top_gainers_losers

        self.get = async_to_raw_response_wrapper(
            top_gainers_losers.get,
        )


class TopGainersLosersResourceWithStreamingResponse:
    def __init__(self, top_gainers_losers: TopGainersLosersResource) -> None:
        self._top_gainers_losers = top_gainers_losers

        self.get = to_streamed_response_wrapper(
            top_gainers_losers.get,
        )


class AsyncTopGainersLosersResourceWithStreamingResponse:
    def __init__(self, top_gainers_losers: AsyncTopGainersLosersResource) -> None:
        self._top_gainers_losers = top_gainers_losers

        self.get = async_to_streamed_response_wrapper(
            top_gainers_losers.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from ..._models import BaseModel

__all__ = ["ListGetNewResponse", "ListGetNewResponseItem"]


class ListGetNewResponseItem(BaseModel):
    id: Optional[str] = None
    """coin ID"""

    activated_at: Optional[float] = None
    """timestamp when coin was activated on CoinGecko"""

    name: Optional[str] = None
    """coin name"""

    symbol: Optional[str] = None
    """coin symbol"""


ListGetNewResponse: TypeAlias = List[ListGetNewResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["AssetPlatformGetParams"]


class AssetPlatformGetParams(TypedDict, total=False):
    filter: Literal["nft"]
    """apply relevant filters to results"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["PingGetResponse"]


class PingGetResponse(BaseModel):
    gecko_says: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ...._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.onchain.pools import megafilter_get_params
from ....types.onchain.pools.megafilter_get_response import MegafilterGetResponse

__all__ = ["MegafilterResource", "AsyncMegafilterResource"]


class MegafilterResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> MegafilterResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return MegafilterResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MegafilterResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return MegafilterResourceWithStreamingResponse(self)

    def get(
        self,
        *,
        buy_tax_percentage_max: float | NotGiven = NOT_GIVEN,
        buy_tax_percentage_min: float | NotGiven = NOT_GIVEN,
        buys_duration: Literal["5m", "1h", "6h", "24h"] | NotGiven = NOT_GIVEN,
        buys_max: int | NotGiven = NOT_GIVEN,
        buys_min: int | NotGiven = NOT_GIVEN,
        checks: str | NotGiven = NOT_GIVEN,
        dexes: str | NotGiven = NOT_GIVEN,
        fdv_usd_max: float | NotGiven = NOT_GIVEN,
        fdv_usd_min: float | NotGiven = NOT_GIVEN,
        h24_volume_usd_max: float | NotGiven = NOT_GIVEN,
        h24_volume_usd_min: float | NotGiven = NOT_GIVEN,
        include: str | NotGiven = NOT_GIVEN,
        networks: str | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        pool_created_hour_max: float | NotGiven = NOT_GIVEN,
        pool_created_hour_min: float | NotGiven = NOT_GIVEN,
        reserve_in_usd_max: float | NotGiven = NOT_GIVEN,
        reserve_in_usd_min: float | NotGiven = NOT_GIVEN,
        sell_tax_percentage_max: float | NotGiven = NOT_GIVEN,
        sell_tax_percentage_min: float | NotGiven = NOT_GIVEN,
        sells_duration: Literal["5m", "1h", "6h", "24h"] | NotGiven = NOT_GIVEN,
        sells_max: int | NotGiven = NOT_GIVEN,
        sells_min: int | NotGiven = NOT_GIVEN,
        sort: Literal[
            "m5_trending",
            "h1_trending",
            "h6_trending",
            "h24_trending",
            "h24_tx_count_desc",
            "h24_volume_usd_desc",
            "h24_price_change_percentage_desc",
            "pool_created_at_desc",
        ]
        | NotGiven = NOT_GIVEN,
        tx_count_duration: Literal["5m", "1h", "6h", "24h"] | NotGiven = NOT_GIVEN,
        tx_count_max: int | NotGiven = NOT_GIVEN,
        tx_count_min: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MegafilterGetResponse:
        """
        This endpoint allows you to **query pools based on various filters across all
        networks on GeckoTerminal**

        Args:
          buy_tax_percentage_max: maximum buy tax percentage

          buy_tax_percentage_min: minimum buy tax percentage

          buys_duration: duration for buy transactions metric Default value: 24h

          buys_max: maximum number of buy transactions

          buys_min: minimum number of buy transactions

          checks: filter options for various checks, comma-separated if more than one Available
              values: `no_honeypot`, `good_gt_score`, `on_coingecko`, `has_social`

          dexes: filter pools by DEXes, comma-separated if more than one DEX ID refers to
              [/networks/{network}/dexes](/reference/dexes-list)

          fdv_usd_max: maximum fully diluted value in USD

          fdv_usd_min: minimum fully diluted value in USD

          h24_volume_usd_max: maximum 24hr volume in USD

          h24_volume_usd_min: minimum 24hr volume in USD

          include: attributes to include, comma-separated if more than one to include Available
              values: `base_token`, `quote_token`, `dex`, `network`

          networks: filter pools by networks, comma-separated if more than one Network ID refers to
              [/networks](/reference/networks-list)

          page: page through results Default value: 1

          pool_created_hour_max: maximum pool age in hours

          pool_created_hour_min: minimum pool age in hours

          reserve_in_usd_max: maximum reserve in USD

          reserve_in_usd_min: minimum reserve in USD

          sell_tax_percentage_max: maximum sell tax percentage

          sell_tax_percentage_min: minimum sell tax percentage

          sells_duration: duration for sell transactions metric Default value: 24h

          sells_max: maximum number of sell transactions

          sells_min: minimum number of sell transactions

          sort: sort the pools by field Default value: h6_trending

          tx_count_duration: duration for transaction count metric Default value: 24h

          tx_count_max: maximum transaction count

          tx_count_min: minimum transaction count

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/onchain/pools/megafilter",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "buy_tax_percentage_max": buy_tax_percentage_max,
                        "buy_tax_percentage_min": buy_tax_percentage_min,
                        "buys_duration": buys_duration,
                        "buys_max": buys_max,
                        "buys_min": buys_min,
                        "checks": checks,
                        "dexes": dexes,
                        "fdv_usd_max": fdv_usd_max,
                        "fdv_usd_min": fdv_usd_min,
                        "h24_volume_usd_max": h24_volume_usd_max,
                        "h24_volume_usd_min": h24_volume_usd_min,
                        "include": include,
                        "networks": networks,
                        "page": page,
                        "pool_created_hour_max": pool_created_hour_max,
                        "pool_created_hour_min": pool_created_hour_min,
                        "reserve_in_usd_max": reserve_in_usd_max,
                        "reserve_in_usd_min": reserve_in_usd_min,
                        "sell_tax_percentage_max": sell_tax_percentage_max,
                        "sell_tax_percentage_min": sell_tax_percentage_min,
                        "sells_duration": sells_duration,
                        "sells_max": sells_max,
                        "sells_min": sells_min,
                        "sort": sort,
                        "tx_count_duration": tx_count_duration,
                        "tx_count_max": tx_count_max,
                        "tx_count_min": tx_count_min,
                    },
                    megafilter_get_params.MegafilterGetParams,
                ),
            ),
            cast_to=MegafilterGetResponse,
        )


class AsyncMegafilterResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncMegafilterResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/coingecko/coingecko-python#accessing-raw-response-data-eg-headers
        """
        return AsyncMegafilterResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMegafilterResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/coingecko/coingecko-python#with_streaming_response
        """
        return AsyncMegafilterResourceWithStreamingResponse(self)

    async def get(
        self,
        *,
        buy_tax_percentage_max: float | NotGiven = NOT_GIVEN,
        buy_tax_percentage_min: float | NotGiven = NOT_GIVEN,
        buys_duration: Literal["5m", "1h", "6h", "24h"] | NotGiven = NOT_GIVEN,
        buys_max: int | NotGiven = NOT_GIVEN,
        buys_min: int | NotGiven = NOT_GIVEN,
        checks: str | NotGiven = NOT_GIVEN,
        dexes: str | NotGiven = NOT_GIVEN,
        fdv_usd_max: float | NotGiven = NOT_GIVEN,
        fdv_usd_min: float | NotGiven = NOT_GIVEN,
        h24_volume_usd_max: float | NotGiven = NOT_GIVEN,
        h24_volume_usd_min: float | NotGiven = NOT_GIVEN,
        include: str | NotGiven = NOT_GIVEN,
        networks: str | NotGiven = NOT_GIVEN,
        page: int | NotGiven = NOT_GIVEN,
        pool_created_hour_max: float | NotGiven = NOT_GIVEN,
        pool_created_hour_min: float | NotGiven = NOT_GIVEN,
        reserve_in_usd_max: float | NotGiven = NOT_GIVEN,
        reserve_in_usd_min: float | NotGiven = NOT_GIVEN,
        sell_tax_percentage_max: float | NotGiven = NOT_GIVEN,
        sell_tax_percentage_min: float | NotGiven = NOT_GIVEN,
        sells_duration: Literal["5m", "1h", "6h", "24h"] | NotGiven = NOT_GIVEN,
        sells_max: int | NotGiven = NOT_GIVEN,
        sells_min: int | NotGiven = NOT_GIVEN,
        sort: Literal[
            "m5_trending",
            "h1_trending",
            "h6_trending",
            "h24_trending",
            "h24_tx_count_desc",
            "h24_volume_usd_desc",
            "h24_price_change_percentage_desc",
            "pool_created_at_desc",
        ]
        | NotGiven = NOT_GIVEN,
        tx_count_duration: Literal["5m", "1h", "6h", "24h"] | NotGiven = NOT_GIVEN,
        tx_count_max: int | NotGiven = NOT_GIVEN,
        tx_count_min: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MegafilterGetResponse:
        """
        This endpoint allows you to **query pools based on various filters across all
        networks on GeckoTerminal**

        Args:
          buy_tax_percentage_max: maximum buy tax percentage

          buy_tax_percentage_min: minimum buy tax percentage

          buys_duration: duration for buy transactions metric Default value: 24h

          buys_max: maximum number of buy transactions

          buys_min: minimum number of buy transactions

          checks: filter options for various checks, comma-separated if more than one Available
              values: `no_honeypot`, `good_gt_score`, `on_coingecko`, `has_social`

          dexes: filter pools by DEXes, comma-separated if more than one DEX ID refers to
              [/networks/{network}/dexes](/reference/dexes-list)

          fdv_usd_max: maximum fully diluted value in USD

          fdv_usd_min: minimum fully diluted value in USD

          h24_volume_usd_max: maximum 24hr volume in USD

          h24_volume_usd_min: minimum 24hr volume in USD

          include: attributes to include, comma-separated if more than one to include Available
              values: `base_token`, `quote_token`, `dex`, `network`

          networks: filter pools by networks, comma-separated if more than one Network ID refers to
              [/networks](/reference/networks-list)

          page: page through results Default value: 1

          pool_created_hour_max: maximum pool age in hours

          pool_created_hour_min: minimum pool age in hours

          reserve_in_usd_max: maximum reserve in USD

          reserve_in_usd_min: minimum reserve in USD

          sell_tax_percentage_max: maximum sell tax percentage

          sell_tax_percentage_min: minimum sell tax percentage

          sells_duration: duration for sell transactions metric Default value: 24h

          sells_max: maximum number of sell transactions

          sells_min: minimum number of sell transactions

          sort: sort the pools by field Default value: h6_trending

          tx_count_duration: duration for transaction count metric Default value: 24h

          tx_count_max: maximum transaction count

          tx_count_min: minimum transaction count

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/onchain/pools/megafilter",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "buy_tax_percentage_max": buy_tax_percentage_max,
                        "buy_tax_percentage_min": buy_tax_percentage_min,
                        "buys_duration": buys_duration,
                        "buys_max": buys_max,
                        "buys_min": buys_min,
                        "checks": checks,
                        "dexes": dexes,
                        "fdv_usd_max": fdv_usd_max,
                        "fdv_usd_min": fdv_usd_min,
                        "h24_volume_usd_max": h24_volume_usd_max,
                        "h24_volume_usd_min": h24_volume_usd_min,
                        "include": include,
                        "networks": networks,
                        "page": page,
                        "pool_created_hour_max": pool_created_hour_max,
                        "pool_created_hour_min": pool_created_hour_min,
                        "reserve_in_usd_max": reserve_in_usd_max,
                        "reserve_in_usd_min": reserve_in_usd_min,
                        "sell_tax_percentage_max": sell_tax_percentage_max,
                        "sell_tax_percentage_min": sell_tax_percentage_min,
                        "sells_duration": sells_duration,
                        "sells_max": sells_max,
                        "sells_min": sells_min,
                        "sort": sort,
                        "tx_count_duration": tx_count_duration,
                        "tx_count_max": tx_count_max,
                        "tx_count_min": tx_count_min,
                    },
                    megafilter_get_params.MegafilterGetParams,
                ),
            ),
            cast_to=MegafilterGetResponse,
        )


class MegafilterResourceWithRawResponse:
    def __init__(self, megafilter: MegafilterResource) -> None:
        self._megafilter = megafilter

        self.get = to_raw_response_wrapper(
            megafilter.get,
        )


class AsyncMegafilterResourceWithRawResponse:
    def __init__(self, megafilter: AsyncMegafilterResource) -> None:
        self._megafilter = megafilter

        self.get = async_to_raw_response_wrapper(
            megafilter.get,
        )


class MegafilterResourceWithStreamingResponse:
    def __init__(self, megafilter: MegafilterResource) -> None:
        self._megafilter = megafilter

        self.get = to_streamed_response_wrapper(
            megafilter.get,
        )


class AsyncMegafilterResourceWithStreamingResponse:
    def __init__(self, megafilter: AsyncMegafilterResource) -> None:
        self._megafilter = megafilter

        self.get = async_to_streamed_response_wrapper(
            megafilter.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["OhlcvGetTimeframeParams"]


class OhlcvGetTimeframeParams(TypedDict, total=False):
    network: Required[str]

    token_address: Required[str]

    aggregate: str
    """
    time period to aggregate each OHLCV Available values (day): `1` Available values
    (hour): `1` , `4` , `12` Available values (minute): `1` , `5` , `15` Default
    value: 1
    """

    before_timestamp: int
    """return OHLCV data before this timestamp (integer seconds since epoch)"""

    currency: Literal["usd", "token"]
    """return OHLCV in USD or quote token Default value: usd"""

    include_empty_intervals: bool
    """include empty intervals with no trade data, default: false"""

    limit: int
    """number of OHLCV results to return, maximum 1000 Default value: 100"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .pools import (
    PoolsResource,
    AsyncPoolsResource,
    PoolsResourceWithRawResponse,
    AsyncPoolsResourceWithRawResponse,
    PoolsResourceWithStreamingResponse,
    AsyncPoolsResourceWithStreamingResponse,
)
from .megafilter import (
    MegafilterResource,
    AsyncMegafilterResource,
    MegafilterResourceWithRawResponse,
    AsyncMegafilterResourceWithRawResponse,
    MegafilterResourceWithStreamingResponse,
    AsyncMegafilterResourceWithStreamingResponse,
)
from .trending_search import (
    TrendingSearchResource,
    AsyncTrendingSearchResource,
    TrendingSearchResourceWithRawResponse,
    AsyncTrendingSearchResourceWithRawResponse,
    TrendingSearchResourceWithStreamingResponse,
    AsyncTrendingSearchResourceWithStreamingResponse,
)

__all__ = [
    "MegafilterResource",
    "AsyncMegafilterResource",
    "MegafilterResourceWithRawResponse",
    "AsyncMegafilterResourceWithRawResponse",
    "MegafilterResourceWithStreamingResponse",
    "AsyncMegafilterResourceWithStreamingResponse",
    "TrendingSearchResource",
    "AsyncTrendingSearchResource",
    "TrendingSearchResourceWithRawResponse",
    "AsyncTrendingSearchResourceWithRawResponse",
    "TrendingSearchResourceWithStreamingResponse",
    "AsyncTrendingSearchResourceWithStreamingResponse",
    "PoolsResource",
    "AsyncPoolsResource",
    "PoolsResourceWithRawResponse",
    "AsyncPoolsResourceWithRawResponse",
    "PoolsResourceWithStreamingResponse",
    "AsyncPoolsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["TokenPriceGetIDParams"]


class TokenPriceGetIDParams(TypedDict, total=False):
    contract_addresses: Required[str]
    """
    the contract addresses of tokens, comma-separated if querying more than 1
    token's contract address
    """

    vs_currencies: Required[str]
    """target currency of coins, comma-separated if querying more than 1 currency.

    \\**refers to
    [`/simple/supported_vs_currencies`](/reference/simple-supported-currencies).
    """

    include_24hr_change: bool
    """include 24hr change default: false"""

    include_24hr_vol: bool
    """include 24hr volume, default: false"""

    include_last_updated_at: bool
    """include last updated price time in UNIX , default: false"""

    include_market_cap: bool
    """include market capitalization, default: false"""

    precision: Literal[
        "full", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "17", "18"
    ]
    """decimal place for currency price value"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional

from ..._models import BaseModel

__all__ = ["CirculatingSupplyChartGetResponse"]


class CirculatingSupplyChartGetResponse(BaseModel):
    circulating_supply: Optional[List[List[Union[float, str]]]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["ExchangeGetIDParams"]


class ExchangeGetIDParams(TypedDict, total=False):
    include_tickers: Literal["all", "unexpired"]
    """include tickers data"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .dex_get_params import DexGetParams as DexGetParams
from .pool_get_params import PoolGetParams as PoolGetParams
from .dex_get_response import DexGetResponse as DexGetResponse
from .pool_get_response import PoolGetResponse as PoolGetResponse
from .new_pool_get_params import NewPoolGetParams as NewPoolGetParams
from .dex_get_pools_params import DexGetPoolsParams as DexGetPoolsParams
from .new_pool_get_response import NewPoolGetResponse as NewPoolGetResponse
from .dex_get_pools_response import DexGetPoolsResponse as DexGetPoolsResponse
from .pool_get_address_params import PoolGetAddressParams as PoolGetAddressParams
from .token_get_address_params import TokenGetAddressParams as TokenGetAddressParams
from .trending_pool_get_params import TrendingPoolGetParams as TrendingPoolGetParams
from .pool_get_address_response import PoolGetAddressResponse as PoolGetAddressResponse
from .token_get_address_response import TokenGetAddressResponse as TokenGetAddressResponse
from .trending_pool_get_response import TrendingPoolGetResponse as TrendingPoolGetResponse
from .new_pool_get_network_params import NewPoolGetNetworkParams as NewPoolGetNetworkParams
from .new_pool_get_network_response import NewPoolGetNetworkResponse as NewPoolGetNetworkResponse
from .trending_pool_get_network_params import TrendingPoolGetNetworkParams as TrendingPoolGetNetworkParams
from .trending_pool_get_network_response import TrendingPoolGetNetworkResponse as TrendingPoolGetNetworkResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["DecentralizedFinanceDefiGetResponse", "Data"]


class Data(BaseModel):
    defi_dominance: Optional[str] = None
    """defi dominance"""

    defi_market_cap: Optional[str] = None
    """defi market cap"""

    defi_to_eth_ratio: Optional[str] = None
    """defi to eth ratio"""

    eth_market_cap: Optional[str] = None
    """eth market cap"""

    top_coin_defi_dominance: Optional[float] = None
    """defi top coin dominance"""

    top_coin_name: Optional[str] = None
    """defi top coin name"""

    trading_volume_24h: Optional[str] = None
    """defi trading volume in 24 hours"""


class DecentralizedFinanceDefiGetResponse(BaseModel):
    data: Optional[Data] = None
